@@ -6,11 +6,11 @@ Dancer2::Template::TemplateFlute - Template::Flute wrapper for Dancer2
 
 =head1 VERSION
 
-Version 0.202
+Version 0.203
 
 =cut
 
-our $VERSION = '0.202';
+our $VERSION = '0.203';
 
 use Carp qw/croak/;
 use Dancer2::Core::Types;
@@ -126,10 +126,7 @@ sub render ($$$) {
 
     # determine whether we need to pass an adjust URI to Template::Flute
     if ( my $request = $tokens->{request} ) {
-        my $pos = index( $request->path, $request->path_info );
-        if ( $pos > 0 ) {
-            $args{uri} = substr( $request->path, 0, $pos );
-        }
+        $args{uri} = $request->base->path if $request->base->path ne '/';
     }
 
     if ( my $i18n = $self->i18n_obj ) {
